module completions {

  # Fast lsp implementation for typst.
  export extern tinymist [
    --help(-h)                # Print help
    --version(-V)             # Print version
  ]

  def "nu-complete tinymist completion shell" [] {
    [ "bash" "elvish" "fig" "fish" "powershell" "zsh" "nushell" ]
  }

  # Generates completion script to stdout
  export extern "tinymist completion" [
    shell?: string@"nu-complete tinymist completion shell" # The shell to generate the completion script for. If not provided, it will be inferred from the environment
    --help(-h)                # Print help
  ]

  # Runs language server
  export extern "tinymist lsp" [
    --mirror: string          # Mirror the stdin to the file
    --replay: string          # Replay input from the file
    --font-path: string       # Font paths
    --ignore-system-fonts     # Ensures system fonts won't be searched, unless explicitly included via `--font-path`
    --help(-h)                # Print help
  ]

  # Runs language query
  export extern "tinymist query" [
    --help(-h)                # Print help
  ]

  # Get the documentation for a specific package
  export extern "tinymist query packageDocs" [
    --path: string            # The path of the package to request docs for
    --id: string              # The package of the package to request docs for
    --output(-o): string      # The output path for the requested docs
    --help(-h)                # Print help
  ]

  # Check a specific package
  export extern "tinymist query checkPackage" [
    --path: string            # The path of the package to request docs for
    --id: string              # The package of the package to request docs for
    --output(-o): string      # The output path for the requested docs
    --help(-h)                # Print help
  ]

  # Print this message or the help of the given subcommand(s)
  export extern "tinymist query help" [
  ]

  # Get the documentation for a specific package
  export extern "tinymist query help packageDocs" [
  ]

  # Check a specific package
  export extern "tinymist query help checkPackage" [
  ]

  # Print this message or the help of the given subcommand(s)
  export extern "tinymist query help help" [
  ]

  # Runs language server for tracing some typst program
  export extern "tinymist trace-lsp" [
    --persist
    --rpc-kind: string
    --mirror: string          # Mirror the stdin to the file
    --replay: string          # Replay input from the file
    input?: string            # Path to input Typst file
    --root: string            # Configures the project root (for absolute paths)
    --input: string           # Add a string key-value pair visible through `sys.inputs`
    --font-path: string       # Font paths
    --ignore-system-fonts     # Ensures system fonts won't be searched, unless explicitly included via `--font-path`
    --package-path: string    # Custom path to local packages, defaults to system-dependent location
    --package-cache-path: string # Custom path to package cache, defaults to system-dependent location
    --creation-timestamp: string # The document's creation date formatted as a UNIX timestamp
    --cert: string            # Path to CA certificate file for network access, especially for downloading typst packages
    --help(-h)                # Print help
  ]

  def "nu-complete tinymist preview refresh_style" [] {
    [ "onSave" "onType" ]
  }

  def "nu-complete tinymist preview preview_mode" [] {
    [ "document" "slide" ]
  }

  # Runs preview server
  export extern "tinymist preview" [
    --partial-rendering       # Only render visible part of the document. This can improve performance but still being experimental
    --invert-colors: string   # Invert colors of the preview (useful for dark themes without cost). Please note you could see the origin colors when you hover elements in the preview
    --task-id: string         # Used by lsp for identifying the task
    --refresh-style: string@"nu-complete tinymist preview refresh_style" # Used by lsp for controlling the preview refresh style
    input?: string            # Path to input Typst file
    --root: string            # Configures the project root (for absolute paths)
    --input: string           # Add a string key-value pair visible through `sys.inputs`
    --font-path: string       # Font paths
    --ignore-system-fonts     # Ensures system fonts won't be searched, unless explicitly included via `--font-path`
    --package-path: string    # Custom path to local packages, defaults to system-dependent location
    --package-cache-path: string # Custom path to package cache, defaults to system-dependent location
    --creation-timestamp: string # The document's creation date formatted as a UNIX timestamp
    --cert: string            # Path to CA certificate file for network access, especially for downloading typst packages
    --preview-mode: string@"nu-complete tinymist preview preview_mode" # Preview mode
    --data-plane-host: string # Data plane server will bind to this address. Note: if it equals to `static_file_host`, same address will be used
    --control-plane-host: string # Control plane server will bind to this address
    --host: string            # (File) Host for the preview server. Note: if it equals to `data_plane_host`, same address will be used
    --not-primary             # Let it not be the primary instance
    --no-open                 # Don't open the preview in the browser after compilation
    --help(-h)                # Print help (see more with '--help')
  ]

  # Probes existence (Nop run)
  export extern "tinymist probe" [
    --help(-h)                # Print help
  ]

  # Print this message or the help of the given subcommand(s)
  export extern "tinymist help" [
  ]

  # Generates completion script to stdout
  export extern "tinymist help completion" [
  ]

  # Runs language server
  export extern "tinymist help lsp" [
  ]

  # Runs language query
  export extern "tinymist help query" [
  ]

  # Get the documentation for a specific package
  export extern "tinymist help query packageDocs" [
  ]

  # Check a specific package
  export extern "tinymist help query checkPackage" [
  ]

  # Runs language server for tracing some typst program
  export extern "tinymist help trace-lsp" [
  ]

  # Runs preview server
  export extern "tinymist help preview" [
  ]

  # Probes existence (Nop run)
  export extern "tinymist help probe" [
  ]

  # Print this message or the help of the given subcommand(s)
  export extern "tinymist help help" [
  ]

}

export use completions *
